@@ -26,6 +26,7 @@ TODO_QUEUE_NAME = "To Do Queue"
 def get_token_url():
     return TrelloApi(apikey=TRELLO_API_KEY).get_token_url("black-belt")
 
+
 def get_api():
     api = TrelloApi(apikey=TRELLO_API_KEY)
     api.set_token(config['trello']['access_token'])
@@ -39,7 +40,7 @@ def get_column(name, board_id=None):
         board_id = config['trello']['work_board_id']
 
     columns = api.boards.get_list(board_id)
-    column  = None
+    column = None
 
     for col in columns:
         if col['name'] == name:
@@ -50,6 +51,7 @@ def get_column(name, board_id=None):
 
     return column
 
+
 def get_current_working_ticket():
     api = get_api()
 
@@ -87,12 +89,12 @@ def pause_ticket(ticket):
     column = get_column(name=config['trello']['pause_column_name'])
     api.cards.update_idList(ticket['id'], column['id'])
 
+
 def comment_ticket(ticket, comment):
     api = get_api()
     api.cards.new_action_comment(ticket['id'], comment)
 
 
-
 def migrate_label(label, board, board_to, column, column_to):
     api = get_api()
 
@@ -122,7 +124,6 @@ def migrate_label(label, board, board_to, column, column_to):
             if l['color'] == final_label:
                 filtered_cards.append(c)
 
-
     board_to_info = api.boards.get(board_to)
     board_to_columns = api.boards.get_list(board_to_info['id'])
 
@@ -139,6 +140,7 @@ def migrate_label(label, board, board_to, column, column_to):
     for card in filtered_cards:
         migrate_card(api, card, target_column)
 
+
 def migrate_card(api, card, target_column):
     print("Moving card %(id)s: %(name)s" % card)
 
@@ -169,7 +171,7 @@ def get_conversion_items(api, card_list, story_card, story_list):
     return (todo_list, [c for c in list_items if c['state'] == 'incomplete' and not c['name'].startswith('https://trello.com/c/')])
 
 
-def schedule_list(story_card, story_list=None, owner=None):
+def schedule_list(story_card, story_list=None, owner=None, label=None):
     """
     Looks for Story Card, finds a list and migrate all non-card items to card,
     replacing the items with links to them.
@@ -192,17 +194,19 @@ def schedule_list(story_card, story_list=None, owner=None):
     else:
         owner = api.members.get(owner)
 
-
-    work_queue = get_column(TODO_QUEUE_NAME)    
+    work_queue = get_column(TODO_QUEUE_NAME)
 
     todo_list, conversion_items = get_conversion_items(api, card_list, story_card, story_list)
 
     for item in conversion_items:
         desc = "Part of %(url)s" % story_card
         card = api.cards.new(name=item['name'], desc=desc, idList=work_queue['id'])
-        api.cards.new_member(card['id'], owner['id'])
 
         create_item(api=api, checklist_id=todo_list['id'], name=card['url'], pos=item['pos'])
         api.checklists.delete_checkItem_idCheckItem(idCheckItem=item['id'], checklist_id=todo_list['id'])
 
+        api.cards.new_member(card['id'], owner['id'])
+        if label:
+            api.cards.new_label(card['id'], label)
+
     print "Done"
